==> portal-contribuinte-3.163.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/estornoDeducaoCreditoDA.sql <==
with contagemestorno as (select nrestorno, nranoestorno, count(1) as qtdregistrosestorno from tcededucaocreditodaest group by nrestorno,nranoestorno),
contagemestornodeducao as (select dtestorno, nranoestorno, nrdeducao, nranodeducao, cdcontroleleiato, count(1) as qtdregistrosestornodeducao from tcededucaocreditodaest group by dtestorno, nranoestorno, nrdeducao, nranodeducao, cdcontroleleiato)
select 	tdcdaest.idtcededucaocreditodaest,
		tdcdaest.cdcontroleleiato,
		tdcdaest.dtestorno,
		tdcdaest.vlestorno,
		tdcdaest.nrestorno,
		tdcdaest.nranoestorno,
		tdcdaest.dsmotivo,
		tdcda.nrdeducao,
		tdcda.nranodeducao,
		tdcda.dtdeducao,
		tdcda.nranodivida,
		ce.qtdregistrosestorno,
		ced.qtdregistrosestornodeducao,
		tel.codigo as escopolei,
        coalesce(lag(tdcdaest.nrestorno, 1) over (order by idtcededucaocreditodaest), 0) as nrestornoanterior
from tcededucaocreditodaest tdcdaest
join contagemestorno ce on ce.nrestorno = tdcdaest.nrestorno and ce.nranoestorno = tdcdaest.nranoestorno
left join contagemestornodeducao ced on ced.dtestorno = tdcdaest.dtestorno
and ced.nranoestorno = tdcdaest.nranoestorno
and ced.nrdeducao = tdcdaest.nrdeducao
and ced.nranodeducao = tdcdaest.nranodeducao
and ced.cdcontroleleiato = tdcdaest.cdcontroleleiato
left join tcededucaocreditoda tdcda on tdcda.nrdeducao = tdcdaest.nrdeducao and tdcda.nranodeducao = tdcdaest.nranodeducao
left join cgato cg on cg.entidade = :entidade and cg.idato = tdcda.cdcontroleleiato
left join tipoescopolei tel on tel.id = cg.idtipoescopolei
where tdcdaest.dtestorno between :dataInicial and :dataFinal

==> portal-contribuinte-4.106.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/estornoDeducaoCreditoDA.sql <==
with contagemestorno as (select nrestorno, nranoestorno, count(1) as qtdregistrosestorno from tcededucaocreditodaest group by nrestorno,nranoestorno),
contagemestornodeducao as (select dtestorno, nranoestorno, nrdeducao, nranodeducao, cdcontroleleiato, count(1) as qtdregistrosestornodeducao from tcededucaocreditodaest group by dtestorno, nranoestorno, nrdeducao, nranodeducao, cdcontroleleiato)
select 	tdcdaest.idtcededucaocreditodaest,
		tdcdaest.cdcontroleleiato,
		tdcdaest.dtestorno,
		tdcdaest.vlestorno,
		tdcdaest.nrestorno,
		tdcdaest.nranoestorno,
		tdcdaest.dsmotivo,
		tdcda.nrdeducao,
		tdcda.nranodeducao,
		tdcda.dtdeducao,
		tdcda.nranodivida,
		ce.qtdregistrosestorno,
		coalesce(ced.qtdregistrosestornodeducao, 1) as qtdregistrosestornodeducao,
		tel.codigo as escopolei,
        coalesce(lag(tdcdaest.nrestorno, 1) over (order by idtcededucaocreditodaest), 0) as nrestornoanterior
from tcededucaocreditodaest tdcdaest
join contagemestorno ce on ce.nrestorno = tdcdaest.nrestorno and ce.nranoestorno = tdcdaest.nranoestorno
left join contagemestornodeducao ced on ced.dtestorno = tdcdaest.dtestorno
and ced.nranoestorno = tdcdaest.nranoestorno
and ced.nrdeducao = tdcdaest.nrdeducao
and ced.nranodeducao = tdcdaest.nranodeducao
and ced.cdcontroleleiato = tdcdaest.cdcontroleleiato
left join tcededucaocreditoda tdcda on tdcda.nrdeducao = tdcdaest.nrdeducao and tdcda.nranodeducao = tdcdaest.nranodeducao
left join cgato cg on cg.entidade = :entidade and cg.idato = tdcda.cdcontroleleiato
left join tipoescopolei tel on tel.id = cg.idtipoescopolei
where tdcdaest.dtestorno between :dataInicial and :dataFinal
